==> haskell-lsp-types-1.6.0.0-85-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-types
version:              1.6.0.0
visibility:           public
id:                   lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb
key:                  lsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  d010df87989b9a8379b0612c8de76144
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-types-1.6.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-types-1.6.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.0-fIIuT8laV65dJgS55XZCb
depends:
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0 binary-0.8.9.0
    containers-0.6.5.1 data-default-0.7.1.1-JYvfHll1aet2HYdPlRdwv9
    deepseq-1.4.6.1 dlist-1.0-LNr75TD4CZoKEEzkBmhWjA exceptions-0.10.4
    filepath-1.4.2.2 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    mod-0.2.0.1-AQHRY81UY789XuHU2wjU3u mtl-2.2.2
    network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh
    safe-0.3.21-98IVtOx0Wmj8cqPHUtTkEF
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    some-1.0.5-L5glA67mR8RJufLDsA2lRz template-haskell-2.18.0.0
    text-1.2.5.0 unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types-1.6.0.1-41.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.6.0.1
visibility:           public
id:                   lsp-types-1.6.0.1-IulO3RKUhD3JqzHgKSkrqs
key:                  lsp-types-1.6.0.1-IulO3RKUhD3JqzHgKSkrqs
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  657840277f209a401677ebb545b39086
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol Language.LSP.Types.Uri.OsPath

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types
hs-libraries:         HSlsp-types-1.6.0.1-IulO3RKUhD3JqzHgKSkrqs
depends:
    Diff-0.4.1-Jc1TR9aaNUv129X0zlHNSG
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1 binary-0.8.9.1
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    filepath-1.4.2.2 hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj
    lens-5.2.3-7k2QwsHyLcVK6NgbwpIzej
    mod-0.2.0.1-Gi7RwD2JXKA3b0qHTJ6K7f mtl-2.2.2
    network-uri-2.6.4.2-6a0tnrWM371Ip5S0wD8Wxe
    safe-0.3.21-9t18UaHoT5jA6SQBJagYvS
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui
    some-1.0.6-33UPTY2v022DFo5SyHLB0b template-haskell-2.19.0.0
    text-2.0.2 unordered-containers-0.2.20-WenrpHtwHKIVom5hXYF7C

haddock-interfaces:   /usr/share/doc/haskell-lsp-types/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
